<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package VW Job Board
 */

if ( ! function_exists( 'vw_job_board_the_attached_image' ) ) :
/**
 * Prints the attached image with a link to the next attached image.
 */
function vw_job_board_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'vw_job_board_attachment_size', array( 1200, 1200 ) );
	$next_attachment_url = wp_get_attachment_url();
	$attachment_ids 	 = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    =>  1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	wp_reset_postdata();

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id )
			$next_attachment_url = get_attachment_link( $next_id );

		// or get the URL of the first image attachment.
		else
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" rel="attachment">%2$s</a>',
		esc_url( $next_attachment_url ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category
 */
function vw_job_board_categorized_blog() {
	if ( false === ( $vw_job_board_all_the_cool_cats = get_transient( 'vw_job_board_all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$vw_job_board_all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$vw_job_board_all_the_cool_cats = count( $vw_job_board_all_the_cool_cats );

		set_transient( 'vw_job_board_all_the_cool_cats', $vw_job_board_all_the_cool_cats );
	}

	if ( '1' != $vw_job_board_all_the_cool_cats ) {
		// This blog has more than 1 category so vw_job_board_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so vw_job_board_categorized_blog should return false
		return false;
	}
}

if ( ! function_exists( 'vw_job_board_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 * @since vw-job-board
 */
function vw_job_board_the_custom_logo() {	
	the_custom_logo();
}
endif;

/**
 * Flush out the transients used in vw_job_board_categorized_blog
 */
function vw_job_board_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'vw_job_board_all_the_cool_cats' );
}
add_action( 'edit_category', 'vw_job_board_category_transient_flusher' );
add_action( 'save_post',     'vw_job_board_category_transient_flusher' );

add_theme_support( 'admin-bar', array( 'callback' => 'vw_job_board_my_admin_bar_css') );
function vw_job_board_my_admin_bar_css(){
?>
<style type="text/css" media="screen">	
	html body { margin-top: 0px !important; }
</style>
<?php
}

/*-- Custom metafield --*/
function vw_job_board_custom_job_field() {
  	add_meta_box( 'bn_meta', __( 'VW Job Board Meta Fields', 'vw-job-board' ), 'vw_job_board_meta_technology_callback', 'post', 'normal', 'high' );
}
if (is_admin()){
  	add_action('admin_menu', 'vw_job_board_custom_job_field');
}

function vw_job_board_meta_technology_callback( $post ) {
  	wp_nonce_field( basename( __FILE__ ), 'vw_job_board_technology_meta' );
  	$bn_stored_meta = get_post_meta( $post->ID );
  	$vw_job_board_technology = get_post_meta( $post->ID, 'vw_job_board_technology', true );
  	$vw_job_board_feature1 = get_post_meta( $post->ID, 'vw_job_board_feature1', true );
  	$vw_job_board_feature2 = get_post_meta( $post->ID, 'vw_job_board_feature2', true );
  	$vw_job_board_feature3 = get_post_meta( $post->ID, 'vw_job_board_feature3', true );
  	$vw_job_board_feature4 = get_post_meta( $post->ID, 'vw_job_board_feature4', true );
  	$vw_job_board_price = get_post_meta( $post->ID, 'vw_job_board_price', true );
  	$vw_job_board_applicants = get_post_meta( $post->ID, 'vw_job_board_applicants', true );
  	?>
  	<div id="custom_meta_feilds">
	    <table id="list">
	      	<tbody id="the-list" data-wp-lists="list:meta">
		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Techology :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_technology" id="vw_job_board_technology" value="<?php echo esc_attr($vw_job_board_technology); ?>" />
		          	</td>
		        </tr>

		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Feature 1 :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_feature1" id="vw_job_board_feature1" value="<?php echo esc_attr($vw_job_board_feature1); ?>" />
		          	</td>
		        </tr>
		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Feature 2 :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_feature2" id="vw_job_board_feature2" value="<?php echo esc_attr($vw_job_board_feature2); ?>" />
		          	</td>
		        </tr>
		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Feature 3 :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_feature3" id="vw_job_board_feature3" value="<?php echo esc_attr($vw_job_board_feature3); ?>" />
		          	</td>
		        </tr>
		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Feature 4 :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_feature4" id="vw_job_board_feature4" value="<?php echo esc_attr($vw_job_board_feature4); ?>" />
		          	</td>
		        </tr>

		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Price :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_price" id="vw_job_board_price" value="<?php echo esc_attr($vw_job_board_price); ?>" />
		          	</td>
		        </tr>
		        <tr id="meta-8">
		          	<td class="left">
		            	<?php esc_html_e( 'Applicants :', 'vw-job-board' )?>
		          	</td>
		          	<td class="left">
		            	<input type="text" name="vw_job_board_applicants" id="vw_job_board_applicants" value="<?php echo esc_attr($vw_job_board_applicants); ?>" />
		          	</td>
		        </tr>
	      	</tbody>
	    </table>
  	</div>
  	<?php
}

function vw_job_board_save( $post_id ) {
  	if (!isset($_POST['vw_job_board_technology_meta']) || !wp_verify_nonce( strip_tags( wp_unslash( $_POST['vw_job_board_technology_meta']) ), basename(__FILE__))) {
      	return;
  	}
  	if (!current_user_can('edit_post', $post_id)) {
   		return;
  	}
  	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
    	return;
  	}
  	if( isset( $_POST[ 'vw_job_board_technology' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_technology', strip_tags( wp_unslash( $_POST[ 'vw_job_board_technology' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_feature1' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_feature1', strip_tags( wp_unslash( $_POST[ 'vw_job_board_feature1' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_feature2' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_feature2', strip_tags( wp_unslash( $_POST[ 'vw_job_board_feature2' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_feature3' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_feature3', strip_tags( wp_unslash( $_POST[ 'vw_job_board_feature3' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_feature4' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_feature4', strip_tags( wp_unslash( $_POST[ 'vw_job_board_feature4' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_price' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_price', strip_tags( wp_unslash( $_POST[ 'vw_job_board_price' ]) ) );
  	}

  	if( isset( $_POST[ 'vw_job_board_applicants' ] ) ) {
    	update_post_meta( $post_id, 'vw_job_board_applicants', strip_tags( wp_unslash( $_POST[ 'vw_job_board_applicants' ]) ) );
  	}
}
add_action( 'save_post', 'vw_job_board_save' );